@@ -17,11 +17,16 @@
 	     (not (member font (w32-font-list))))
     (w32-auto-regist-bdf-font font bdf 0)
     ;; Set bitmap16 font to all fontsets.
-    (let ((fset (fontset-list)))
-      (while fset
-	(when (string-match "fixed-medium-r" (cdr (assoc 'bitmap 
-				 (assoc (car fset) global-fontset-alist))))
-	  (set-fontset-font (car fset) 'bitmap "bitmap16"))
-	(setq fset (cdr fset))))))
+    (add-hook 'emacs-startup-hook
+      (lambda ()
+	(let ((fset (fontset-list))
+	      name)
+	  (while fset
+	    (setq name (cdr (assoc 'bitmap (assoc (car fset)
+						  global-fontset-alist))))
+	    (when (or (not name)
+		      (string-match "fixed-medium-r" name))
+	      (set-fontset-font (car fset) 'bitmap "bitmap16"))
+	    (setq fset (cdr fset))))))))
 
 ;;; auto-autoloads.el ends here
